import request from "@/plugins/request";

/**
 * @description 查询科目列表
 */
export const getSubjectsListHttp = (data: FetchSubjectsListQuery) => {
  return request.post<
    FetchSubjectsListQuery,
    MultiplePageData<SubjectsListInfo>
  >("/api/paper/page", data);
};

/**
 * @description 导入科目
 */
export const importSubjectsHttp = (data: FormData) => {
  /** multipart/form-data */
  return request.post<unknown, null>("/api/paper/import-course", data, {
    headers: {
      "Content-Type": "multipart/form-data",
    },
  });
};

/**
 * @description 导入试卷结构
 */

export const importPaperStructHttp = (data: FormData) => {
  return request.post<unknown, null>("/api/paper/import-struct-subject", data, {
    headers: {
      "Content-Type": "multipart/form-data",
    },
  });
};

/**
 * @description 导出试卷结构
 */

export const downloadPaperStructHttp = (data: FetchSubjectsListQuery) => {
  return request.post<Blob>("/api/paper/export-subjective", data, {
    responseType: "blob",
    download: true,
  });
};

/**
 * @description 下载科目导入模板
 */
export const downloadSubjectTemplateHttp = () => {
  return request.post<Blob>("/api/paper/template-course", null, {
    responseType: "blob",
    download: true,
  });
};

/**
 * @description 下载试卷结构导入模板
 */
export const downloadPaperStructTemplateHttp = () => {
  return request.post<Blob>("/api/paper/template-struct", null, {
    responseType: "blob",
    download: true,
  });
};
