import request from "@/plugins/request";
import { getUserInfo, cacheUserInfo } from "@/utils/auth";

/**
 * @description 获取当前用户信息
 */
export const getUserInfoHttp = (
  force: boolean = false
): Promise<SystemUserInfo> => {
  const cachedUserInfo = getUserInfo();

  return cachedUserInfo && !force
    ? Promise.resolve(cacheUserInfo(cachedUserInfo))
    : request
        .post<null, SystemUserInfo>("/api/user/my/info")
        .then(cacheUserInfo);
};

/**
 * @description 获取用户列表
 */

export const getUserListHttp = (data: FetchUserListQuery) => {
  return request.post<FetchUserListQuery, MultiplePageData<UserInfo>>(
    "/api/user/page",
    data
  );
};

/**
 * @description 新增/修改用户信息
 */
export const editUserInfoHttp = (data: EditUserInfo) => {
  return request.post<BaseSchoolInfo, null>("/api/user/save", data);
};

/**
 * @description 启用/禁用用户
 */
export const updateUserStatusHttp = (data: {
  enable: boolean;
  ids: number[];
}) => {
  return request.post<unknown, null>("/api/user/toggle", data);
};

/**
 * @description 重置用户密码
 */
export const resetUserPwdHttp = (data: { passwd: string; userId: string }) => {
  return request.post<unknown, null>("/api/user/reset-passwd", data);
};

/**
 * @description 导入用户
 */

export const importUserHttp = (data: FormData) => {
  /** multipart/form-data */
  return request.post<unknown, null>("/api/user/import", data, {
    headers: {
      "Content-Type": "multipart/form-data",
    },
  });
};

/**
 * @description 下载导入模板
 */

export const downloadImportUserHttp = () => {
  return request.post<Blob>("/api/user/template", null, {
    responseType: "blob",
    download: true,
  });
};

export const exportUserData = (data: any) => {
  return request.post<Blob>("/api/user/export", data, {
    responseType: "blob",
    download: true,
  });
};
